# gofile

## Info

A Python wrapper for the GoFile API.

**Currently in beta, expect bugs!**

## Installation

    $ python3 -m pip install gofile

## Usage

See [documentation](https://github.com/Codec04/gofile/wiki/) for usage examples.

## Links

[PyPI](https://pypi.org/project/gofile/)

[GoFile](https://gofile.io/)

[Documentation](https://github.com/Codec04/gofile/wiki/)

[Bugs](https://github.com/Codec04/gofile/issues/)
